from setuptools import setup, find_packages

setup(
    name='krumii',
    version='0.1',
    packages=find_packages(),
    author='kurumii',
    description='Handy tools for Python',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)